@@ -36,11 +36,11 @@ Backup::EZ - Simple backups based on rsync
 
 =head1 VERSION
 
-Version 0.30
+Version 0.31
 
 =cut
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 =head1 SYNOPSIS
 
@@ -180,7 +180,6 @@ sub _get_dirs {
     my @dirs;
 
     foreach my $dir ( @{ $self->{conf}->{dir} } ) {
-
         push( @dirs, Backup::EZ::Dir->new($dir) );
     }
 
@@ -327,12 +326,12 @@ sub _rsync_no_recursion {
 sub _rsync2 {
     my $self = shift;
     my %a    = @_;
-
+    
     my $dir          = $a{dir} or confess "missing dir arg";
     my $link_dest    = $a{link_dest};
     my $archive_opts = $a{archive_opts} || '-az';
     my $extra_opts   = $a{extra_opts} || [];
-
+    
     my $cmd;
     my $login;
 
@@ -373,7 +372,25 @@ sub _rsync2 {
             $dir,                           # dest sub dir
         );
     }
-
+   
+    #
+    # fail safe bailout in case of bug
+    # 
+    my @cmd = split(/\s+/, $cmd);
+    my $link_cnt = 0;
+    foreach my $c (@cmd) {
+        if ($c =~ /link-dest/) {
+            $link_cnt++    
+        }    
+    }
+    
+    if ($link_cnt > 1) {
+        confess "too many link-dest args: $cmd";     
+    }
+   
+    #
+    # ok execute 
+    # 
     $self->_debug($cmd);
     system($cmd);
     
@@ -428,7 +445,7 @@ sub _full_backup_chunked {
     $self->_rsync2(
         dir          => $dir->dirname,
         archive_opts => ARCHIVE_NO_RECURSE_OPTS,
-        extra_opts   => $dir->excludes,
+        extra_opts   => $dir->excludes(),
     );
 
     my @entries = read_dir( $dir->dirname, prefix => 1 );
@@ -438,7 +455,7 @@ sub _full_backup_chunked {
             $self->_rsync2(
                 dir          => $entry,
                 archive_opts => DEFAULT_ARCHIVE_OPTS,
-                extra_opts   => $dir->excludes,
+                extra_opts   => $dir->excludes(),
             );
         }
     }
@@ -455,7 +472,7 @@ sub _full_backup {
         $self->_rsync2(
             dir          => $dir->dirname,
             archive_opts => DEFAULT_ARCHIVE_OPTS,
-            extra_opts   => $dir->excludes,
+            extra_opts   => $dir->excludes(),
         );
     }
 }
@@ -465,26 +482,25 @@ sub _inc_backup_chunked {
     my $dir             = shift;
     my $last_backup_dir = shift;
     my $link_dest       = shift;
-
+   
     $self->_rsync2(
         dir          => $dir->dirname,
         archive_opts => ARCHIVE_NO_RECURSE_OPTS,
-        extra_opts   => $dir->excludes,
+        extra_opts   => $dir->excludes(),
         link_dest    => $link_dest,
     );
 
     my @entries = read_dir( $dir->dirname, prefix => 0 );
     
     foreach my $entry (@entries) {
-
+        
         my $abs_entry = sprintf( '%s/%s', $dir->dirname, $entry );
 
         if ( -d $abs_entry ) {
-
             $self->_rsync2(
                 dir          => $abs_entry,
                 archive_opts => DEFAULT_ARCHIVE_OPTS,
-                extra_opts   => $dir->excludes,
+                extra_opts   => $dir->excludes(),
                 link_dest    => sprintf( '%s/%s', $link_dest, $entry ),
             );
         }
@@ -510,7 +526,7 @@ sub _inc_backup {
         $self->_rsync2(
             dir          => $dir->dirname,
             archive_opts => DEFAULT_ARCHIVE_OPTS,
-            extra_opts   => $dir->excludes,
+            extra_opts   => $dir->excludes(),
             link_dest    => $link_dest,
         );
     }
@@ -564,7 +580,7 @@ sub backup {
     $self->_mk_dest_dir( $self->_get_dest_tmp_dir, $self->{dryrun} );
 
     foreach my $dir ( $self->_get_dirs ) {
-
+        
         my $dirname = $dir->dirname();
         if ( -d $dirname ) {
 
